fuse_exit: Exit 'fuse()' early

View source: R/fuse.R

fuse_exitR Documentation

Exit fuse() early

Description

Stop fuse() from processing the remaining code chunks and text blocks. This function is meant to be called inside a code chunk to end the document early.

Usage

fuse_exit(append = "")

Arguments

append

A character string to be appended to the fuse output after the current code chunk.

Value

Invisible NULL.


litedown documentation built on July 11, 2026, 9:07 a.m.