| fuse_exit | R Documentation |
fuse() earlyStop fuse() from processing the remaining code chunks and text blocks. This
function is meant to be called inside a code chunk to end the document early.
fuse_exit(append = "")
append |
A character string to be appended to the fuse output after the current code chunk. |
Invisible NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.