Learn R Programming

litedown (version 0.11)

fuse_exit: Exit fuse() early

Description

Stop fuse() from processing the remaining code chunks and text blocks. This function is meant to be called inside a code chunk to end the document early.

Usage

fuse_exit(append = "")

Value

Invisible NULL.

Arguments

append

A character string to be appended to the fuse output after the current code chunk.